@@ -15,6 +15,10 @@ def create_all_metadata(
     schema,
     source_bucket,
     source_folder,
+    include_op_column=True,
+    include_timestamp_column=True,
+    include_derived_columns=False,
+    include_objects=False,
     filter_function=None,
 ):
     """Perform the whole process: get table list, filter it and create metadata folder
@@ -48,6 +52,22 @@ def create_all_metadata(
         If you want to filter the list of tables after extracting it, pass a function
         here. The function should take a single argument: a list of tuples in the form
         (table name, tablespace). It should return a list of table names (not tuples).
+
+    include_op_column (boolean):
+        If True, adds a column called 'Op' for operation type - I, U or D
+        This data is automatically added by AWS DMS ongoing replication tasks.
+
+    include_timestamp_column (string):
+        If True, adds a column called 'extraction_timestamp'.
+        This data is added by DMS if the source extra connection attribute is set.
+
+    include_derived_columns (boolean):
+        If True, adds four columns: mojap_latest_record, mojap_start_datetime,
+        mojap_end_datetime, mojap_deleted_record.
+
+    include_objects (boolean):
+        If True, will include metadata for DB_TYPE_OBJECT columns as array<character>.
+        Leave False to ignore these columns - AWS DMS doesn't extract them.
     """
     get_table_list(connection, save_folder, title, schema, filter_function)
     create_metadata_folder(
@@ -58,11 +78,25 @@ def create_all_metadata(
         schema,
         source_bucket,
         source_folder,
+        include_op_column,
+        include_timestamp_column,
+        include_derived_columns,
+        include_objects,
     )
 
 
 def create_metadata_folder(
-    connection, save_folder, title, description, schema, source_bucket, source_folder,
+    connection,
+    save_folder,
+    title,
+    description,
+    schema,
+    source_bucket,
+    source_folder,
+    include_op_column=True,
+    include_timestamp_column=True,
+    include_derived_columns=False,
+    include_objects=False,
 ):
     """
     Creates a folder of metadata readable by etl_manager's read_database_folder.
@@ -92,6 +126,22 @@ def create_metadata_folder(
 
     source_folder (str):
         Folder/prefix within the S3 bucket for the relevant source data.
+
+    include_op_column (boolean):
+        If True, adds a column called 'Op' for operation type - I, U or D
+        This data is automatically added by AWS DMS ongoing replication tasks.
+
+    include_timestamp_column (string):
+        If True, adds a column called 'extraction_timestamp'.
+        This data is added by DMS if the source extra connection attribute is set.
+
+    include_derived_columns (boolean):
+        If True, adds four columns: mojap_latest_record, mojap_start_datetime,
+        mojap_end_datetime, mojap_deleted_record.
+
+    include_objects (boolean):
+        If True, will include metadata for DB_TYPE_OBJECT columns as array<character>.
+        Leave False to ignore these columns - AWS DMS doesn't extract them.
     """
     # Create destination folder if it doesn't already exist
     destination = Path(save_folder) / title
@@ -114,10 +164,10 @@ def create_metadata_folder(
         tables=table_list,
         schema=schema,
         location=destination,
-        include_op_column=True,
-        include_timestamp_column=True,
-        include_derived_columns=False,
-        include_objects=False,
+        include_op_column=include_op_column,
+        include_timestamp_column=include_timestamp_column,
+        include_derived_columns=include_derived_columns,
+        include_objects=include_objects,
         connection=connection,
     )
 
@@ -196,8 +246,12 @@ def create_json_for_tables(
         This data is added by DMS if the source extra connection attribute is set.
 
     include_derived_columns (boolean):
-        If True, adds 5 datetime columns: mojap_extraction_datetime,
-        mojap_start_datetime, mojap_end_datetime, mojap_latest_record, mojap_image_tag.
+        If True, adds four columns: mojap_latest_record, mojap_start_datetime,
+        mojap_end_datetime, mojap_deleted_record.
+
+    include_objects (boolean):
+        If True, will include metadata for DB_TYPE_OBJECT columns as array<character>.
+        Leave False to ignore these columns - AWS DMS doesn't extract them.
 
     connection (database connection object):
         The database connection to query - for example a cx_Oracle.connect() object.
@@ -231,6 +285,7 @@ def create_json_for_tables(
                     include_op_column,
                     include_timestamp_column,
                     include_derived_columns,
+                    include_objects,
                 )
                 write_json(metadata, Path(location) / f"{table.lower()}.json")
 
@@ -288,8 +343,8 @@ def get_table_meta(
         This data is added by AWS DMS, when configured as an extra connection attribute.
 
     include_derived_columns (boolean):
-        If True, adds 5 datetime columns: mojap_extraction_datetime,
-        mojap_start_datetime, mojap_end_datetime, mojap_latest_record, mojap_image_tag.
+        If True, adds four columns: mojap_latest_record, mojap_start_datetime,
+        mojap_end_datetime, mojap_deleted_record.
 
     include_objects (boolean):
         If True, will include metadata for DB_TYPE_OBJECT columns as array<character>.
@@ -331,7 +386,7 @@ def get_table_meta(
         columns.append(
             {
                 "name": "extraction_timestamp",
-                "type": "character",
+                "type": "datetime",
                 "description": "DMS extraction timestamp",
                 "nullable": False,
             }
@@ -378,37 +433,27 @@ def get_table_meta(
     ]
     derived_columns = [
         {
-            "name": "mojap_extraction_datetime",
-            "type": "datetime",
-            "description": "When this data was extracted from its source database",
+            "name": "mojap_latest_record",
+            "type": "boolean",
+            "description": "If the record is current",
             "nullable": False,
         },
         {
             "name": "mojap_start_datetime",
             "type": "datetime",
-            "description": "When this record started to "
-            "be the current data for this primary key",
+            "description": "When the record became current",
             "nullable": False,
         },
         {
             "name": "mojap_end_datetime",
             "type": "datetime",
-            "description": "When this record stopped being the "
-            "current data for this primary key",
+            "description": "When the record ceased to be current",
             "nullable": False,
         },
         {
-            "name": "mojap_latest_record",
+            "name": "mojap_deleted_record",
             "type": "boolean",
-            "description": "Whether this record is currently "
-            "the latest one for this primary key",
-            "nullable": False,
-        },
-        {
-            "name": "mojap_image_tag",
-            "type": "character",
-            "description": "A tag of the docker image used "
-            "to run the pipeline tasks, if relevant",
+            "description": "If the record has been deleted",
             "nullable": False,
         },
     ]
